.. module:: brownie.caching

Caching
=======

This module provides various caching mechanisms and utilities.

.. autoclass:: cached_property

.. autoclass:: CacheBase
   :members:

.. autoclass:: LRUCache
   :members: decorate

.. autoclass:: LFUCache
   :members: decorate
